@@ -1,5 +1,6 @@
 from .exceptions import NoPlayerFoundError
 from .objects.objects import HypixelPlayer
+from .objects.leaderboards import Leaderboards
 import aiohttp
 
 HYPIXEL_API = "https://api.hypixel.net"
@@ -12,3 +13,10 @@ async def get_player_by_uuid(uuid: str, api: str) -> HypixelPlayer:
             # is null
             raise NoPlayerFoundError
     return HypixelPlayer(json)
+
+
+async def get_leaderboards(api: str) -> Leaderboards:
+    async with aiohttp.ClientSession() as session:
+        json = await (await session.get(f"{HYPIXEL_API}/leaderboards?key={api}")).json()
+    # theoretically this shouldn't error ever, there is no input to be invalid it should be static
+    return Leaderboards(api, json)
